---
title: spark
---

## Operations on PySpark columns

:::gentropy.common.spark.nullify_empty_array
:::gentropy.common.spark.get_top_ranked_in_window
:::gentropy.common.spark.get_record_with_minimum_value
:::gentropy.common.spark.get_record_with_maximum_value
:::gentropy.common.spark.normalise_column
:::gentropy.common.spark.string2camelcase
:::gentropy.common.spark.column2camel_case
:::gentropy.common.spark.get_value_from_row
:::gentropy.common.spark.safe_array_union
:::gentropy.common.spark.sort_array_struct_by_columns
:::gentropy.common.spark.extract_column_name
:::gentropy.common.spark.order_array_of_structs_by_field
:::gentropy.common.spark.order_array_of_structs_by_two_fields
:::gentropy.common.spark.map_column_by_dictionary
:::gentropy.common.spark.create_empty_column_if_not_exists
:::gentropy.common.spark.calculate_harmonic_sum
:::gentropy.common.spark.clean_strings_from_symbols
:::gentropy.common.spark.filter_array_struct

## Operations on PySpark schemas (meta transformations)

:::gentropy.common.spark.enforce_schema
:::gentropy.common.spark.get_nested_struct_schema
:::gentropy.common.spark.get_struct_field_schema

## DataFrame transformations

:::gentropy.common.spark.convert_from_wide_to_long
:::gentropy.common.spark.convert_from_long_to_wide
:::gentropy.common.spark.pivot_df
:::gentropy.common.spark.rename_all_columns
